@@ -149,7 +149,14 @@ class AppDataSet(ORMBase):
 
     @property
     def file_save_folder(self):
-        return os.path.join(self.app.app_folder_path, 'data_set_data/data_set_' + str(self.id))
+        """Returns a path on disk of a folder specific to the data set to save files to.
+
+        Additionally, creates the folder for the data set if it does not yet exist.
+        """
+        folder = os.path.join(self.app.app_folder_path, 'data_set_data', 'data_set_' + str(self.id))
+        if not os.path.exists(folder):
+            os.makedirs(folder)
+        return folder
 
     def add(self, obj):
         """Adds a TropofyBase object to the Data Set.
@@ -235,14 +242,8 @@ class AppDataSet(ORMBase):
         return next((ref for ref in self.saved_image_references if ref.image_name == name), None)
 
     def get_path_of_file_in_data_set_folder(self, file_name):
-        """Returns a path on disk, within a folder for the data set that is safe to save files to.
-
-        Additionally, creates the folder for the data set if it does not yet exist.
-        """
-        folder = self.file_save_folder
-        if not os.path.exists(folder):
-            os.makedirs(folder)
-        return os.path.join(folder, file_name)
+        """Returns a path on disk, within a folder specific for the data set, that is safe to save the file to."""
+        return os.path.join(self.file_save_folder, file_name)
 
     def get_var(self, name):
         """Get a variable that was set with :func:`tropofy.app.AppDataSet.set_var`"""
