@@ -103,19 +103,18 @@ class ClassWsMapping(object):
     def create_ordered_mappings_from_sqla_classes(cls, sqla_classes=None, include_parameters_if_any=True):
         """
         :param sqla_classes: List of SQLA classes to create mappings for. If None, assumes create for all classes in app.
-        :type sqla_classes: list
-
         :returns: list of :class:`tropofy.database.read_write_xl.ClassWsMapping`
-        :rtype: list        
+        :rtype: list
         """
+        sqla_classes = sqla_classes if sqla_classes is not None else []
+        if not isinstance(sqla_classes, collections.Iterable):
+            raise TypeError("param sqla_classes must be an iterable (e.g. list)")
+
         request = threadlocal.get_current_request()
         class_ws_mappings = []
         if request.app:
-            tables_mapped_to_classes = request.app.get_tables_mapped_to_classes_for_app()
-            ordered_tables = TropofyDbMetaData.get_dependency_sorted_tables([k.name for k in tables_mapped_to_classes])
-            for table in ordered_tables:
-                class_ = tables_mapped_to_classes.get(table)
-
+            tables_mapped_to_classes = request.app.get_dependency_ordered_dict_of_tables_mapped_to_classes_for_app()
+            for table, class_ in tables_mapped_to_classes.iteritems():
                 if sqla_classes:  # Map all classes if none specified. Also only map classes in sqla_classes
                     if class_ not in sqla_classes:
                         class_ = None
@@ -178,35 +177,55 @@ class ClassWsMapping(object):
             return True
         raise ExcelError('The first row in a sheet must be the column names. Sheet %s is missing the following columns %s' % (self.ws_name, ", ".join(list(required_ws_column_names_as_set - headers_as_set))))
 
-def create_excel_wb_for_tables(data_set, tables):
-    class_ws_mappings = ClassWsMapping.create_ordered_mappings_from_sqla_classes(sqla_classes=tables, include_parameters_if_any=False)
-    for m in class_ws_mappings:
-        m.objects = data_set.query(m.get_class()).all()
-        m.objects.sort(key=attrgetter(*m.required_ws_column_names))
-    return create_excel_wb_from_class_mappings(data_set, ordered_class_ws_mappings=class_ws_mappings)
 
 def create_excel_string_repr(data_set, ordered_class_ws_mappings=None):
-    wb = create_excel_wb_from_class_mappings(data_set, ordered_class_ws_mappings=None)
-    return save_virtual_workbook(wb)
+    """
+    Create an Excel file as a string, which has a tab for each class in ordered_class_ws_mappings
 
-def create_excel_string_repr_for_tables(data_set, tables):
-    wb = create_excel_wb_for_tables(data_set, tables)
+    :param data_set: The DataSet object on which queries can be made to access the apps data.
+    :type data_set: :class:`tropofy.app.AppDataSet`
+    :param ordered_class_ws_mappings:
+    :type ordered_class_ws_mappings: list of ClassWsMapping
+    :return: str
+    """
+    if ordered_class_ws_mappings is None:
+        ordered_class_ws_mappings = ClassWsMapping.create_ordered_mappings_from_sqla_classes()
+        if data_set:
+            for mapping in ordered_class_ws_mappings:
+                mapping.objects = mapping.get_objects(data_set, mapping.class_)
+    wb = create_excel_wb_from_class_mappings(ordered_class_ws_mappings)
     return save_virtual_workbook(wb)
 
 
-def create_example_data_set_from_excel(data_set, file_name_with_path):  # Deprecated! Todo: Replace with load_data_from_excel_file_on_disk. Shouldn't be creating data sets in here.
-    wb = xlrd.open_workbook(file_name_with_path)
-    if not data_set:
-        raise Exception('create_example_data_set_from_excel is deprecated. Please use load_data_from_excel_file_on_disk')
-    load_data_from_excel(wb, data_set)
+def create_excel_string_repr_for_sqla_classes(data_set, sqla_classes):
+    """
+    Create an Excel file as a string, which has a tab for each SQLA class passed with SQLA_classes.
 
+    :param data_set: The DataSet object on which queries can be made to access the apps data.
+    :type data_set: :class:`tropofy.app.AppDataSet`
+    :param sqla_classes: A list of SQLA ORM defined classes
+    :type sqla_classes: list of SQLA classes
+    :return: str
+    """
+    wb = create_excel_wb_for_sqla_classes(data_set, sqla_classes)
+    return save_virtual_workbook(wb)
+
+def create_excel_wb_for_sqla_classes(data_set, sqla_classes):
+    """
+    Create an openpyxl Workbook, which has a tab for each SQLA class passed with SQLA_classes.
+
+    :param data_set: The DataSet object on which queries can be made to access the apps data.
+    :type data_set: :class:`tropofy.app.AppDataSet`
+    :param sqla_classes: A list of SQLA ORM defined classes
+    :type sqla_classes: list of SQLA classes
+    :return: openpyxl.Workbook
+    """
+    ordered_class_ws_mappings = ClassWsMapping.create_ordered_mappings_from_sqla_classes(sqla_classes=sqla_classes, include_parameters_if_any=False)
+    for m in ordered_class_ws_mappings:
+        m.objects = data_set.query(m.get_class()).all()
+        m.objects.sort(key=attrgetter(*m.required_ws_column_names))
+    return create_excel_wb_from_class_mappings(ordered_class_ws_mappings=ordered_class_ws_mappings)
 
-def create_data_set_from_excel_file_in_memory(file_in_memory):  # TodoL Replace with load_data_from_excel_file_in_memory. Shouldn't be creating data sets in here.
-    wb = xlrd.open_workbook(file_contents=file_in_memory.file.read())  # openpyxl cannot read a file from a string, otherwise I would have used it
-    request = threadlocal.get_current_request()
-    if request.app:
-        data_set = request.app.create_new_data_set_for_user(authenticated_userid(request), None, "Imported '%s'" % (file_in_memory.filename))
-        return load_data_from_excel(wb, data_set)
 
 def load_data_from_excel_file_on_disk(data_set, file_name_with_path, ordered_class_ws_mappings=None):
     wb = xlrd.open_workbook(file_name_with_path)
@@ -295,18 +314,11 @@ def load_data_from_excel(wb, data_set, ordered_class_ws_mappings=None):
     return progress_messages
 
 
-def create_excel_wb_from_class_mappings(data_set, ordered_class_ws_mappings=None):
+def create_excel_wb_from_class_mappings(ordered_class_ws_mappings):
     """
-    :param wb: Excel workbook opened with xlrd
     :param ordered_class_ws_mappings: Ordered list of :class:`tropofy.database.read_write_xl.ClassWsMapping`. Will be processed in this order (makes safe for dependencies)
-    :type ordered_class_ws_mappings: list
+    :type ordered_class_ws_mappings: ClassWsMapping list
     """
-    if not ordered_class_ws_mappings:
-        ordered_class_ws_mappings = ClassWsMapping.create_ordered_mappings_from_sqla_classes()
-        if data_set:
-            for mapping in ordered_class_ws_mappings:
-                mapping.objects = mapping.get_objects(data_set, mapping.class_)
-
     wb = openpyxl.Workbook()
     if wb.get_sheet_by_name('Sheet') != None:
         wb.remove_sheet(wb.get_sheet_by_name('Sheet'))
@@ -314,9 +326,9 @@ def create_excel_wb_from_class_mappings(data_set, ordered_class_ws_mappings=None
     for mapping in ordered_class_ws_mappings:
         worksheet = wb.create_sheet()
         try:
-            worksheet.title = mapping.ws_name  # The limit is 32 characters I think
-        except Exception as e:
-            raise e
+            worksheet.title = mapping.ws_name[:29]  # Excel ws names have a limit of 31 characters. Restrict to first 29 to allow excel to append numbers if names aren't unique.
+        except openpyxl.shared.exc.SheetTitleException:
+            raise openpyxl.shared.exc.SheetTitleException("Could not create > 100 worksheets with names with duplicate first 29 characters.")
         col_names = mapping.required_ws_column_names
         if col_names:
             for col in col_names:
@@ -329,7 +341,14 @@ def create_excel_wb_from_class_mappings(data_set, ordered_class_ws_mappings=None
                     except AttributeError:
                         print('Object in ClassWsMappingForExport.objects does not match ClassWsMappingForExport object and col definition')
                         raise
-                    worksheet.cell(row=i + 1, column=j).value = value  # Add one to row to skip col names header row.
+                    row_num = i + 1  # Add one to row to skip col names header row.
+                    if isinstance(value, basestring):  # Have to force string. Otherwise will automatically coerce to things. Eg scientific notation: '110E04' will save as 1100000.0
+                        worksheet.cell(row=row_num, column=j).set_value_explicit(
+                            value=value,
+                            data_type=openpyxl.cell.Cell.TYPE_STRING
+                        )
+                    else:
+                        worksheet.cell(row=row_num, column=j).value = value  # Add one to row to skip col names header row.
     return wb
 
 
@@ -359,11 +378,11 @@ def _get_table_rows_as_tuple_list(engine, table, data_set_id):  # Todo: Remove f
     return result
 
 
-def _create_excel_workbook_for_tables_with_optional_data(tables, engine, data_set_id=None):  # Note this is not SQLAlchemy ORM driven():
+def _create_excel_workbook_for_tables_with_optional_data(tables, engine, data_set_id=None):  # TODO: Remove? Is this being used anywhere? Note this is not SQLAlchemy ORM driven():
     wb = openpyxl.Workbook()
     if wb.get_sheet_by_name('Sheet') != None:
         wb.remove_sheet(wb.get_sheet_by_name('Sheet'))
-    ordered_tables = TropofyDbMetaData.get_dependency_sorted_tables([k.name for k in tables])
+    ordered_tables = TropofyDbMetaData.get_dependency_sorted_tables([TropofyDbMetaData.TableNameAndSchema(k.name, k.schema) for k in tables])
     for table in ordered_tables:
         worksheet = wb.create_sheet()
         worksheet.title = table.name
@@ -386,4 +405,58 @@ def _create_excel_workbook_for_tables_with_optional_data(tables, engine, data_se
 # ws helper function
 def _ws_headers_as_set(ws):
     headers = ws.row_values(0)
-    return set([col.encode('ascii', 'ignore') for col in headers if col != None])
\ No newline at end of file
+    return set([col.encode('ascii', 'ignore') for col in headers if col != None])
+
+
+### DEPCRECATED FUNCTIONS ###
+# TODO: Remove deprecated functions. Have to check not being used anywhere first! This is definitely being used in Clermont
+
+# TODO: Deprecated! Remove when OK to do so (check production apps)
+def create_excel_string_repr_for_tables(data_set, tables):
+    """
+    Deprecated! Very misleading method and param name 'tables'.
+     In SQLA, 'tables' are very very different to the ORM classes. This method also implies non SQLA 'tables' can be used. Wrong!
+
+    Use create_excel_string_repr_for_sqla_classes instead.
+    """
+    return create_excel_string_repr_for_sqla_classes(
+        data_set=data_set,
+        sqla_classes=tables,
+    )
+
+# TODO: Deprecated! Remove when OK to do so. Currently used in Clermont TestCase.write_current_results_to_csv
+def create_excel_wb_for_tables(data_set, tables):
+    """
+    Deprecated! Very misleading method and param name 'tables'.
+     In SQLA, 'tables' are very very different to the ORM classes. This method also implies non SQLA 'tables' can be used. Wrong!
+
+    Use create_excel_wb_for_sqla_classes instead.
+    """
+    return create_excel_wb_for_sqla_classes(data_set, tables)
+
+# TODO: Deprecated! Remove when OK to do so (check production apps)
+def create_data_set_from_excel_file_in_memory(file_in_memory):
+    """
+    Deprecated! Use load_data_from_excel_file_in_memory. Shouldn't be creating data sets in here.
+
+    Upgrade instructions: Need to create the data set elsewhere, and then call load_data_from_excel_file_in_memory to populate the data set
+    """
+    wb = xlrd.open_workbook(file_contents=file_in_memory.file.read())  # openpyxl cannot read a file from a string, otherwise I would have used it
+    request = threadlocal.get_current_request()
+    if request.app:
+        data_set = request.app.create_new_data_set_for_user(authenticated_userid(request), None, "Imported '%s'" % (file_in_memory.filename))
+        return load_data_from_excel(wb, data_set)
+
+# TODO: Deprecated!
+def create_example_data_set_from_excel(data_set, file_name_with_path):
+    """
+    Deprecated! replace with load_data_from_excel_file_on_disk. Shouldn't be creating data sets in here.
+
+    Name is misleading and doesn't actually create a data set anyway.
+     Upgrade instructions: Simple rename to load_data_from_excel_file_on_disk and everything should work.
+    """
+    wb = xlrd.open_workbook(file_name_with_path)
+    if not data_set:
+        raise Exception('create_example_data_set_from_excel is deprecated. Please use load_data_from_excel_file_on_disk')
+    load_data_from_excel(wb, data_set)
+
