@@ -1,15 +1,15 @@
-'''
+"""
 Author:      www.tropofy.com
 
 Copyright 2013 Tropofy Pty Ltd, all rights reserved.
 
-This source file is part of Tropofy and govered by the Tropofy terms of service
+This source file is part of Tropofy and governed by the Tropofy terms of service
 available at: http://www.tropofy.com/terms_of_service.html
 
 This source file is distributed in the hope that it will be useful, but
 WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 or FITNESS FOR A PARTICULAR PURPOSE. See the license files for details.
-'''
+"""
 
 from sqlalchemy import Column, Text, Float
 from tropofy.database.tropofy_orm import DataSetMixin
@@ -25,7 +25,7 @@ class MyLocation(DataSetMixin):
 
 class MyFirstApp(AppWithDataSets):
     def get_name(self):
-        return "My First App"
+        return "Hello World"
 
     def get_gui(self):
         return [StepGroup(steps=[Step(widgets=[SimpleGrid(MyLocation)])])]
